# Welcome to Connectionist's documentation

This project is a course companion python library for the course [Contemporary neural networks for cognition and cognitive neuroscience](https://drive.google.com/drive/folders/1ZNmK-W8bk3iIH6M5cYzhO_XGhCrxFXzL).

Source code: [https://github.com/JasonLo/connectionist](https://github.com/JasonLo/connectionist)
